@@ -33,7 +33,10 @@ class KGET_EXPORT JobQueue : public QObject
 {
     Q_OBJECT
 public:
-    enum Status { Running, Stopped };
+    enum Status {
+        Running,
+        Stopped
+    };
     typedef QList<Job *>::iterator iterator;
 
     JobQueue(Scheduler *parent);
